import { useNavigation } from "@react-navigation/native";
import { NativeStackNavigationProp } from "@react-navigation/native-stack";
import { Pressable, View, Text, StyleSheet } from "react-native";
import { GlobalStyles } from "../../constants/styles";
import { RootStackParamList } from "../../navigation/LinkingConfiguration";
import { T_Expense, E_ManageExpenseScreenModes } from "../../types";
import { getFormattedDate } from "../../util/date";

interface Props {
  expense: T_Expense;
}

export default function ExpenseItem({ expense }: Props) {
  const navigation = useNavigation<NativeStackNavigationProp<RootStackParamList>>();
  function expensePressHandler() {
    navigation.navigate("Screen_ManageExpense", {
      mode: E_ManageExpenseScreenModes["Edit Expense"],
      expense,
    });
  }

  return (
    <Pressable
      onPress={expensePressHandler}
      style={({ pressed }) => pressed && styles.pressed}
      android_ripple={{ color: GlobalStyles.colors.accent500, foreground: true }}>
      <View style={styles.expenseItem}>
        <View>
          <Text style={[styles.textBase, styles.description]}>{expense?.description}</Text>
          <Text style={styles.textBase}>{getFormattedDate({ date: expense?.date })}</Text>
        </View>
        <View style={styles.amountContainer}>
          <Text style={styles.amount}>{expense?.amount?.toFixed(2)}</Text>
        </View>
      </View>
    </Pressable>
  );
}

const styles = StyleSheet.create({
  pressed: { opacity: 0.75 },
  expenseItem: {
    padding: 12,
    marginVertical: 8,
    backgroundColor: GlobalStyles.colors.primary500,
    flexDirection: "row",
    justifyContent: "space-between",
    borderRadius: 6,
    elevation: 3,
    shadowColor: GlobalStyles.colors.gray500,
    shadowRadius: 4,
    shadowOffset: { width: 1, height: 1 },
    shadowOpacity: 0.4,
  },
  textBase: {
    color: GlobalStyles.colors.primary50,
  },
  description: {
    fontSize: 16,
    marginBottom: 4,
    fontWeight: "bold",
  },
  amountContainer: {
    paddingHorizontal: 12,
    paddingVertical: 4,
    backgroundColor: "white",
    justifyContent: "center",
    alignItems: "center",
    borderRadius: 4,
    minWidth: 80,
  },
  amount: {
    color: GlobalStyles.colors.primary500,
    fontWeight: "bold",
  },
});
